import java.awt.Color;

/*************************************************************************
 *  YOU DO NOT NEED TO MODIFY THIS FILE
 *
 * Taken from section 3.2, An Introduction to Programming (in Java) by Robert
 * Sedgewick and Kevin Wayne
 *
 *  Compilation:  javac Point.java
 *  Execution:    java Point
 *
 *  Immutable data type for 2D points.
 *
 *************************************************************************/

/**
 * Point represents the "point" data type where each point has an x, y position
 * and a color.
 * 
 * @author Keith Vertanen
 * @version 1.0
 * @author Michele Van Dyne
 * @version 1.01
 *
 */
public class Point {
	private static final Color[] colors = new Color[1000];
	private final double x;   // Cartesian
	private final double y;   // coordinates
	private final Color index;

	static {
		for(int i = 0; i < colors.length; i++)
		{
			colors[i] = new Color((float)Math.random(),
					(float)Math.random(),
					(float)Math.random());
		}
	}

	/**
	 * Constructor for the Point class
	 * 
	 * @author Keith Vertanen
	 * @param x represents the x position of the point
	 * @param y represents the y position of the point
	 * 
	 */
	public Point(double x, double y) {
		this.x = x;
		this.y = y;
		index = colors[(int)(Math.random() * colors.length)];
	}

	/**
	 * Calculates the distance between one point and another
	 * 
	 * @author Keith Vertanen
	 * @param that the second point
	 * @return the Euclidean disance between points
	 * 
	 */
	public double distanceTo(Point that) {
		double dx = this.x - that.x;
		double dy = this.y - that.y;
		return Math.sqrt(dx*dx + dy*dy);
	}

	/**
	 * Draws a single point on the window canvas
	 * 
	 * @author Keith Vertanen
	 * 
	 */
	public void draw() {
		StdDraw.point(x, y);
	}

	/**
	 * Draws a line from the invoking point this to that using standard draw
	 * 
	 * @author Keith Vertanen
	 * @param that the second point
	 * 
	 */
	public void drawTo(Point that) {

		StdDraw.setPenColor(index);
		StdDraw.line(this.x, this.y, that.x, that.y);
	}

	// return string representation of this point
	/**
	 * Provides a printable string representation of a point
	 * 
	 * @author Keith Vertanen
	 * @return a String that may be used with System.out.println
	 * 
	 */
	public String toString() {
		return "(" + x + ", " + y + ")";
	}

	// test client
	/**
	 * A test client for testing proper function of the point 
	 * class and methods
	 * 
	 * @author Keith Vertanen
	 * @param args unused
	 * 
	 */
	public static void main(String[] args) {

		// get dimensions
		int w = StdIn.readInt();
		int h = StdIn.readInt();
		StdDraw.setCanvasSize(w, h);
		StdDraw.setXscale(0, w);
		StdDraw.setYscale(0, h);
		StdDraw.setPenRadius(.001);

		StdDraw.show(0);
		// read in and plot points one at at time
		int i = 0;
		while (!StdIn.isEmpty()) {
			double x = StdIn.readDouble();
			double y = StdIn.readDouble();
			Point p = new Point(x, y);
			p.draw();
			if (i % 20 == 0)
				StdDraw.show(0);
			i++;
		}
		StdDraw.show(0);
	}
}
